# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['zwo']

package_data = \
{'': ['*']}

install_requires = \
['parsimonious>=0.10,<0.11',
 'rich>=12.6,<13.0',
 'sco1-misc>=0.1,<0.2',
 'typer[rich]>=0.6,<0.7']

entry_points = \
{'console_scripts': ['zwom = zwo.cli:zwom_cli']}

setup_kwargs = {
    'name': 'zwolang',
    'version': '0.3.0',
    'description': 'Python toolkit for the ZWO minilang',
    'long_description': '# ZWO Minilang\n[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/zwolang)](https://pypi.org/project/zwolang/)\n[![PyPI](https://img.shields.io/pypi/v/zwolang)](https://pypi.org/project/zwolang/)\n[![PyPI - License](https://img.shields.io/pypi/l/zwolang?color=magenta)](https://github.com/sco1/zwom/blob/master/LICENSE)\n[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/sco1/zwom/main.svg)](https://results.pre-commit.ci/latest/github/sco1/zwom/main)\n[![Code style: black](https://img.shields.io/badge/code%20style-black-black)](https://github.com/psf/black)\n[![Open in Visual Studio Code](https://img.shields.io/badge/Open%20in-VSCode.dev-blue)](https://vscode.dev/github.com/sco1/zwom)\n\nPython toolkit for the ZWO minilang.\n\n## Installation\nInstall from PyPi with your favorite `pip` invocation:\n\n```bash\n$ pip install zwolang\n```\n\nYou can confirm proper installation via the `zwom` CLI:\n<!-- [[[cog\nimport cog\nfrom subprocess import PIPE, run\nout = run(["zwom", "--help"], stdout=PIPE, encoding="ascii")\ncog.out(\n    f"```\\n$ zwom --help\\n{out.stdout.rstrip()}\\n```"\n)\n]]] -->\n```\n$ zwom --help\n                                                                               \n Usage: zwom [OPTIONS] COMMAND [ARGS]...                                       \n                                                                               \n+- Options -------------------------------------------------------------------+\n| --help          Show this message and exit.                                 |\n+-----------------------------------------------------------------------------+\n+- Commands ------------------------------------------------------------------+\n| batch    Discover and convert all `*.zwom` files in the given directory.    |\n| single   Convert the specified `*.zwom` file to Zwift\'s `*.zwo`.            |\n+-----------------------------------------------------------------------------+\n```\n<!-- [[[end]]] -->\n\n## The ZWOM File Specification\nThe primary purpose of this package is to provide a simple, human-readable format for constructing Zwift workouts that can be used to generate the actual workout XML. Let\'s call it a `*.zwom` file, or ZWOM.\n\nZWOM files are parsed using a [Parsimonious](https://github.com/erikrose/parsimonious) grammar, as specified below:\n<!-- [[[cog\nfrom textwrap import dedent\nimport cog\nfrom zwo.parser import RAW_GRAMMAR\ncog.out(\n    f"```{dedent(RAW_GRAMMAR)}```"\n)\n]]] -->\n```\nworkout   = ((comment / block) elws*)+ / elws\nblock     = tag ws "{" ((comment / params) / elws)+ "}"\nparams    = (message / value) ","?\nvalue     = tag ws (string / range / rangeval)\n\nmessage   = "@" ws duration ws string\nrange     = rangeval ws "->" ws rangeval\nrangeval  = duration / numeric / zone\nduration  = number ":" number\npercent   = number "%"\nzone      = ("Z" number) / "SS"\nnumeric   = percent / number\nelws      = ws / emptyline\n\ncomment   = ~r"\\;[^\\r\\n]*"\ntag       = ~"[A-Z_]+"\nstring    = ~\'"[^\\"]+"\'\nnumber    = ~"\\d+"\nws        = ~"\\s*"\nemptyline = ws+\n```\n<!-- [[[end]]] -->\n\n### Syntax & Keywords\nLike Zwift\'s built-in workout builder, the ZWO minilang is a block-based system. Blocks are specified using a `<tag> {<block contents>}` format supporting arbitrary whitespace.\n\nInline comments are also supported, denoted by a leading `;`.\n\n### Workout Metadata\nEach ZWO file must begin with a `META` block containing comma-separated parameters:\n\n| Keyword       | Description             | Accepted Inputs                | Optional?         |\n|---------------|-------------------------|--------------------------------|-------------------|\n| `NAME`        | Displayed workout name  | `str`                          | No                |\n| `AUTHOR`      | Workout author          | `str`                          | No                |\n| `DESCRIPTION` | Workout description     | `str`<sup>1</sup>              | No                |\n| `FTP`         | Rider\'s FTP             | `int`                          | Maybe<sup>2</sup> |\n| `TAGS`        | Workout tags            | String of hashtags<sup>3</sup> | Yes               |\n\n1. Multiline strings are supported\n2. Zwift\'s workouts are generated using FTP percentages rather than absolute watts, so your FTP is required if you want to use absolute watts in your ZWOM\n3. Tags are capped at 31 total characters, including spaces and hashtags. Zwift also provides 4 built-in tags (`#RECOVERY`, `#INTERVALS`, `#FTP`, and `#TT`) that may also be added and do not count against this total.\n\n### Workout Blocks\nFollowing the `META` block are your workout blocks:\n\n| Keyword     | Description        |\n|-------------|--------------------|\n| `FREE`      | Free ride          |\n| `COOLDOWN`  | Cooldown           |\n| `INTERVALS` | Intervals          |\n| `RAMP`      | Ramp               |\n| `SEGMENT`   | Steady segment     |\n| `WARMUP`    | Warmup             |\n\n**NOTE:** While there is no specific Ramp block in the workout building UI, some experimental observations have been made:\n  * If a ramp is at the very beginning of the workout, Zwift serializes it as a Warmup block\n  * If there are multiple blocks in a workout and a ramp is at the end, Zwift serializes it as a Cooldown block\n  * If there are multiple blocks in a workout and a ramp is not at the beginning or the end, Zwift serializes it as a Ramp block\n\nWhen writing your `*.zwom` file, these 3 blocks can be used interchangably, and ZWOM will try to match this behavior when outputting its `*.zwo` file. Zwift may do its own normalization if edits are made in the workout UI.\n\n### Workout Block Metadata\nWorkout blocks can contain the following (optionally) comma-separated parameters:\n\n| Keyword    | Description         | Accepted Inputs                                    | Optional?                |\n|------------|---------------------|----------------------------------------------------|--------------------------|\n| `DURATION` | Block duration      | `MM:SS`, Range<sup>1</sup>                         | No                       |\n| `CADENCE`  | Target cadence      | `int`, Range<sup>1,2</sup>                         | Yes                      |\n| `REPEAT`   | Number of intervals | `int`                                              | Only valid for intervals |\n| `POWER`    | Target power        | `int`, `int%`, Zone<sup>3</sup>, Range<sup>1</sup> | Mostly no<sup>4</sup>    |\n| `@`        | Display a message   | `@ MM:SS str`<sup>5</sup>                          | Yes                      |\n\n1. For Interval & Ramp segments, the range syntax can be used to set values for the `<left> -> <right>` segments (e.g. `65% -> 120%` or `Z2 -> Z6`)\n2. Cadence ranges are only valid for Interval segments\n3. Zones may be specified as `Z1-7` or `SS`\n4. Power is ignored for Free segments\n5. Message timestamps are relative to their containing block\n\n### Repeating a Chunk of Blocks\nThe `START_REPEAT` and `END_REPEAT` meta blocks are provided to specify an arbitrary chunk of blocks to repeat. The `START_REPEAT` block must specify a `REPEAT` parameter; `END_REPEAT` accepts no parameters. Nested repeats are not currently supported.\n\nFor example:\n\n```\nSEGMENT {DURATION 2:00, POWER 65%}\nRAMP {\n    DURATION 2:00,\n    POWER 120% -> 140%,\n    @ 0:00 "Here goes the ramp!",\n    @ 1:50 "10 seconds left!",\n}\nSEGMENT {DURATION 2:00, POWER 65%}\nRAMP {\n    DURATION 2:00,\n    POWER 120% -> 140%,\n    @ 0:00 "Here goes the ramp!",\n    @ 1:50 "10 seconds left!",\n}\n```\nBecomes:\n\n```\nSTART_REPEAT {REPEAT 2}\nSEGMENT {DURATION 2:00, POWER 65%}\nRAMP {\n    DURATION 2:00,\n    POWER 120% -> 140%,\n    @ 0:00 "Here goes the ramp!",\n    @ 1:50 "10 seconds left!",\n}\nEND_REPEAT {}\n```\n\n## Sample Workout\n```\n; Here is a workout-level comment!\nMETA {\n    NAME "Sample Workout",\n    AUTHOR "sco1",\n    DESCRIPTION "Here\'s a description!\n\n    Descriptions may be on more than one line too!",\n    TAGS "#RECOVERY #super #sweet #workout",\n    FTP 270,\n}\nFREE {DURATION 10:00}\nINTERVALS {\n    ; Here is a block-level comment!\n    REPEAT 3,\n    DURATION 1:00 -> 0:30,\n    POWER 55% -> 78%,\n    CADENCE 85 -> 110,\n}\nSEGMENT {DURATION 2:00, POWER 65%}\nRAMP {\n    DURATION 2:00,\n    POWER 120% -> 140%,\n    @ 0:00 "Here goes the ramp!",\n    @ 1:50 "10 seconds left!",\n}\nFREE {DURATION 10:00}\n```\n\n![Workout Screenshot](https://raw.githubusercontent.com/sco1/sco1.github.io/master/zwo/sample_zwift_workout.png)\n',
    'author': 'sco1',
    'author_email': 'sco1.git@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/sco1/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.11,<4.0',
}


setup(**setup_kwargs)
